@@ -7,7 +7,7 @@ from ...query import Query, Wait
 
 class Interval(RAlgorithm):
     def __init__(self, databases):
-        self._databases = databases
+        super(Interval, self).__init__(databases)
         self._next_db = 0
         self._info_per_database = {x: 0 for x in range(len(databases))}
 
