@@ -30,4 +30,4 @@ class Generator:
         if database.engine == DatabaseEngine.POSTGRESQL.value:
             return "select count(*) from pg_stat_activity where pid <> pg_backend_pid() and usename = current_user;"
         elif database.engine == DatabaseEngine.MYSQL.value:
-            return "select count(*) from processlist;"
+            return "select count(*) from information_schema.processlist;"
