@@ -37,11 +37,13 @@ class LoadBalancerFactory:
         if LOAD_BALANCER['CUD_ALGORITHM'] == "MULTITHREADING":
             databases = []
             for i, name in enumerate(LOAD_BALANCER['DATABASES']):
-                database = Database(name, {Wait.WAIT.value: WaitWaiter(),
-                                           Wait.DONT_WAIT.value: DontWaitWaiter()},
-                                    QueryExecutor(),
-                                    DATABASES[name]['ENGINE'],
-                                    cls.OperationalErrorGenerator.generate_operational_error(DATABASES[name]['ENGINE']))
+                engine = DATABASES[name]['ENGINE']
+                operational_error = cls.OperationalErrorGenerator.generate_operational_error(DATABASES[name]['ENGINE'])
+                database = Database(name=name, engine=engine, operational_error=operational_error)
+                executor = QueryExecutor(database=database)
+                waiters = {Wait.WAIT.value: WaitWaiter(executor=executor),
+                           Wait.DONT_WAIT.value: DontWaitWaiter(executor=executor)}
+                database.waiters = waiters
                 databases.append(database)
                 database.query_ended.set()
                 thread = threading.Thread(target=database.run_queries, args=(), daemon=True)
@@ -51,7 +53,7 @@ class LoadBalancerFactory:
     @staticmethod
     def _create_cud_algorithm(databases):
         if LOAD_BALANCER['CUD_ALGORITHM'] == "MULTITHREADING":
-            return MultithreadingAlgorithm(databases)
+            return MultithreadingAlgorithm(databases=databases)
 
     @staticmethod
     def _create_r_algorithm(databases):
