@@ -1,4 +1,4 @@
-from datetime import datetime
+import logging
 from time import sleep
 
 import django.db
@@ -24,17 +24,13 @@ class WatchDog():
                         cursor.close()
                     except (database.operational_error, django.db.utils.OperationalError):
                         database.change_status(DatabaseStatus.DOWN.value)
-                        now = datetime.now()
-                        current_time = now.strftime("%H:%M:%S")
-                        print(f"{current_time}   {database.name} went down")
+                        logging.warning(f'WatchDog: {database.name} went down')
                 else:
                     try:
                         django.db.connections[database.name].close()
                         django.db.connections[database.name].connect()
                         database.change_status(DatabaseStatus.RUNNING.value)
                         database.is_up.set()
-                        now = datetime.now()
-                        current_time = now.strftime("%H:%M:%S")
-                        print(f"{current_time}   {database.name} went up")
+                        logging.info(f'WatchDog: {database.name} went up')
                     except (database.operational_error, django.db.utils.OperationalError):
                         pass
